@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 """Test that pyformat runs without crashing on various Python files."""
 
+from __future__ import print_function
 from __future__ import unicode_literals
 
 import os
@@ -157,43 +158,40 @@ def check(args):
             signal.alarm(int(args.timeout))
 
         while filenames:
-            name = os.path.realpath(filenames.pop(0))
-            if not os.path.exists(name):
-                # Invalid symlink.
-                continue
-
-            if name in completed_filenames:
-                sys.stderr.write(
-                    colored('--->  Skipping previously tested ' + name + '\n',
-                            YELLOW))
-                continue
-            else:
-                completed_filenames.update(name)
-
             try:
-                is_directory = os.path.isdir(name)
-            except UnicodeEncodeError:
+                name = os.path.realpath(filenames.pop(0))
+                if not os.path.exists(name):
+                    # Invalid symlink.
+                    continue
+
+                if name in completed_filenames:
+                    sys.stderr.write(
+                        colored(
+                            '--->  Skipping previously tested ' + name + '\n',
+                            YELLOW))
+                    continue
+                else:
+                    completed_filenames.update(name)
+
+                if os.path.isdir(name):
+                    for root, directories, children in os.walk(name):
+                        filenames += [os.path.join(root, f) for f in children
+                                      if f.endswith('.py') and
+                                      not f.startswith('.')]
+
+                        directories[:] = [d for d in directories
+                                          if not d.startswith('.')]
+                else:
+                    verbose_message = '--->  Testing with ' + name
+                    sys.stderr.write(colored(verbose_message + '\n', YELLOW))
+
+                    if not run(os.path.join(name), verbose=args.verbose,
+                               options=options):
+                        return False
+            except (UnicodeDecodeError, UnicodeEncodeError) as exception:
+                # Ignore annoying codec problems on Python 2.
+                print(exception, file=sys.stderr)
                 continue
-
-            if is_directory:
-                for root, directories, children in os.walk(name):
-                    filenames += [os.path.join(root, f) for f in children
-                                  if f.endswith('.py') and
-                                  not f.startswith('.')]
-
-                    directories[:] = [d for d in directories
-                                      if not d.startswith('.')]
-            else:
-                verbose_message = '--->  Testing with '
-                try:
-                    verbose_message += name
-                except UnicodeEncodeError:
-                    verbose_message += '...'
-                sys.stderr.write(colored(verbose_message + '\n', YELLOW))
-
-                if not run(os.path.join(name), verbose=args.verbose,
-                           options=options):
-                    return False
     except TimeoutException:
         sys.stderr.write('Timed out\n')
     finally:
